==> monocdk-1.106.1.tar.gz: package/lib/aws-dms/lib/dms-canned-metrics.generated.d.ts <==
export declare class DMSMetrics {
    static cdcLatencyTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcLatencySourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static availableMemoryAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcChangesDiskTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcChangesMemorySourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcChangesMemoryTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcIncomingChangesSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputBandwidthSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputBandwidthTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputRowsSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputRowsTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cpuAllocatedSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cpuUtilizationAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static freeMemoryAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputBandwidthSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputBandwidthTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputRowsSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputRowsTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static memoryAllocatedAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static memoryUsageAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static swapUsageAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
}

==> monocdk-1.149.0.tar.gz: package/lib/aws-dms/lib/dms-canned-metrics.generated.d.ts <==
export declare class DMSMetrics {
    static cdcLatencyTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcLatencySourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static availableMemoryAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcChangesDiskTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcChangesMemorySourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcChangesMemoryTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcIncomingChangesSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputBandwidthSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputBandwidthTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputRowsSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cdcThroughputRowsTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cpuAllocatedSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static cpuUtilizationAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static freeMemoryAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputBandwidthSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputBandwidthTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputRowsSourceSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static fullLoadThroughputRowsTargetSum(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static memoryAllocatedAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static memoryUsageAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
    static swapUsageAverage(dimensions: {
        ReplicationInstanceIdentifier: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ReplicationInstanceIdentifier: string;
        };
        statistic: string;
    };
}
